@@ -17,7 +17,8 @@ mod value;
 
 pub use self::errors::TomlError;
 pub(crate) use self::key::is_unquoted_char;
-pub(crate) use self::key::simple_key as key_parser;
+pub(crate) use self::key::key as key_path;
+pub(crate) use self::key::simple_key;
 pub(crate) use self::value::value as value_parser;
 
 use self::table::duplicate_key;
@@ -288,7 +289,7 @@ mod tests {
         parsed_eq!(
             parsed,
             "I\'m a string. \"You can quote me\". Name\tJosé\nLocation\tSF. \u{2070E}"
-        )
+        );
     }
 
     #[test]
@@ -419,6 +420,12 @@ trimmed in raw strings.
         }
     }
 
+    #[test]
+    fn time_fraction_truncated() {
+        let input = "1987-07-05T17:45:00.123456789012345Z";
+        parsed_date_time_eq!(input, is_datetime);
+    }
+
     #[test]
     fn trivia() {
         let inputs = [
@@ -613,6 +620,8 @@ that
 key = "value"
 "#,
             r#"hello.world = "a"
+"#,
+            r#"foo = 1979-05-27 # Comment
 "#,
         ];
         for document in &documents {
